@@ -2,9 +2,7 @@
 
 test_that("plot for compare_categories returns the correct output format", {
   db <- plot(compare_categories(datacube = emperors, key = "ID"))
-  expect_type(db, "list")
-  expect_length(db, 11)
-  expect_true(ggplot2::is_ggplot(db))
+  expect_true(inherits(db, c("ggplot", "ggplot2::ggplot")))
   expect_named(db, names(ggplot2::ggplot()))
 })
 
@@ -13,9 +11,9 @@ test_that("compare_categories() returns the correct output format", {
   db1 <- compare_categories(datacube = emperors, key = "ID", variable = "Begin")
   db2 <- compare_categories(datacube = emperors, key = "ID",
                             variable = c("Begin", "End"), category = "conflict")
-  expect_type(db, "list")
-  expect_type(db1, "list")
-  expect_type(db2, "list")
+  expect_true(inherits(db, "compare_categories"))
+  expect_true(inherits(db1, "compare_categories"))
+  expect_true(inherits(db2, "compare_categories"))
   expect_s3_class(db, "tbl")
   expect_s3_class(db1, "tbl")
   expect_s3_class(db2, "tbl")
@@ -42,13 +40,8 @@ test_that("compare_dimensions() returns the correct output format", {
 test_that("compare_overlap() and return the correct output format", {
   db <- compare_overlap(emperors, key = "ID")
   expect_type(db, "list")
-  expect_length(db, 2)
-  expect_s3_class(db, "tbl_df")
   pl <- plot(db)
-  expect_type(pl, "list")
-  expect_length(pl, length(ggplot2::ggplot()))
-  expect_true(ggplot2::is_ggplot(pl))
-  expect_named(pl, names(ggplot2::ggplot()))
+  expect_true(inherits(pl, c("ggplot", "ggplot2::ggplot", "upset_plot")))
 })
 
 test_that("compare_missing() and plot_missing() returns the correct output format", {
@@ -57,7 +50,7 @@ test_that("compare_missing() and plot_missing() returns the correct output forma
   expect_length(db, 6)
   expect_s3_class(db, "tbl_df")
   pl <- plot(db)
-  expect_type(pl, "list")
+  expect_true(inherits(pl, c("ggplot", "ggplot2::ggplot")))
   expect_length(pl, length(ggplot2::ggplot()))
   expect_true(ggplot2::is_ggplot(pl))
   expect_named(pl, names(ggplot2::ggplot()))
